@@ -22,10 +22,10 @@ import pprint
 import sys
 import textwrap
 
-from evariste.cache import Cache
-from evariste.errors import EvaristeError
-from evariste.setup import Setup
-from evariste.utils import expand_path
+from ...cache import Cache
+from ...errors import EvaristeError
+from ...setup import Setup
+from ...utils import expand_path
 
 LOGGER = logging.getLogger(__name__)
 
