@@ -25,8 +25,6 @@ from ...evs.compile.options import get_options
 from ...setup import Setup
 from ...utils import ChangeDir
 
-FORMAT = "%(message)s"
-logging.basicConfig(format=FORMAT)
 LOGGER = logging.getLogger("evariste")
 
 DEFAULT_SETUP = {"changed": {"time": "fs"}}
