@@ -24,24 +24,6 @@ import textwrap
 from ... import VERSION
 
 LOGGER = logging.getLogger("evariste")
-LOGGING_LEVELS = {
-    -1: 100,  # Quiet
-    0: logging.WARNING,
-    1: logging.INFO,
-    2: logging.DEBUG,
-    3: 1,
-}
-
-
-def _get_logging_level(verbose):
-    """Turn command line verbosity into :mod:`logging` verbosity."""
-    if verbose in LOGGING_LEVELS:
-        return LOGGING_LEVELS[verbose]
-    if verbose is None:
-        return LOGGING_LEVELS[0]
-    if verbose > max(LOGGING_LEVELS.keys()):
-        return LOGGING_LEVELS[max(LOGGING_LEVELS.keys())]
-    raise NotImplementedError()
 
 
 def _setup_type(name):
@@ -148,15 +130,7 @@ def commandline_parser():
 def get_options():
     """Return the namespace of (processed) command line options."""
     try:
-        arguments = commandline_parser().parse_args(namespace=Options())
-
-        # Process --verbose and --quiet
-        # pylint: disable=no-member, attribute-defined-outside-init
-        if arguments.quiet:
-            arguments.verbose = -1
-        LOGGER.setLevel(_get_logging_level(arguments.verbose))
-
-        return arguments
+        return commandline_parser().parse_args(namespace=Options())
     except argparse.ArgumentTypeError as error:
         sys.stderr.write(str(error))
         sys.stderr.write("\n")
