@@ -1,4 +1,4 @@
-# Copyright Louis Paternault 2017-2021
+# Copyright Louis Paternault 2017-2022
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -13,73 +13,77 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Actions performed to compile files."""
+"""Actions performed to compile files.
 
+The result of an :class:`action <Action>`
+(Was it sucessful? Which files were used? What is the log? etc.)
+is stored as a :class:`report <Report>`.
+
+If you plan to write your own action plugin, see :ref:`write_action`.
+
+:class:`Action`
+---------------
+
+.. autoclass:: Action
+   :members:
+
+:class:`Report`
+---------------
+
+.. autoclass:: Report
+   :members:
+"""
+
+# Can be removed starting with python3.11
+from __future__ import annotations
+
+import abc
+import contextlib
 import io
 import logging
 import os
+import pathlib
 import threading
+import typing
 
-from evariste import errors, plugins
-from evariste import hooks
+from ... import errors, plugins
+from ...hooks import contexthook
+
+if typing.TYPE_CHECKING:
+    from ...tree import Tree
 
 LOGGER = logging.getLogger(__name__)
 
-################################################################################
-# Cache log
-
-
-class CacheLogHook(hooks.ContextHook):
-    """Hook called before and after compilation of one file."""
-
-    # pylint: disable=too-few-public-methods
-
-    hookname = "File.compile"
-
-    def __init__(self, plugin, tree):
-        super().__init__(plugin)
-        self.tree = tree
-
-    def __exit__(self, *args, **kwargs):
-        """Store the log in cache."""
-        tree = self.tree
-
-        # Saving log into cache
-        self.local.tree[tree.from_source] = tree.report.log
-
-
-class CacheLog(plugins.PluginBase):
-    """Cache compilation log."""
-
-    # pylint: disable=too-few-public-methods
-
-    plugin_type = ""
-    keyword = "cachelog"
-    hooks = [CacheLogHook]
-
 
 ################################################################################
 # Actions
 
 
-class Action(plugins.PluginBase):
-    """Generic action"""
+class Action(plugins.Plugin, metaclass=abc.ABCMeta):
+    """Generic action
+
+    Subclass this to create a new action (see :ref:`write_action`).
+    """
 
     # pylint: disable=too-many-instance-attributes, too-few-public-methods
 
     plugin_type = "action"
-    lock = threading.Lock()
 
-    def compile(self, path):
-        """Compile ``path``, catching :class:`EvaristeError` exceptions.
+    #: A lock shared by every action.
+    #: Can be used for parts of the compilation which are not thread-safe.
+    lock: threading.Lock = threading.Lock()
 
-        This function *must* be thread-safe. It can use `self.lock` if
-        necessary.
+    @abc.abstractmethod
+    def compile(self, path: Tree) -> Report:
+        """Compile ``path``.
+
+        This function *must* be thread-safe.
+        It can use :attr:`Action.lock` if necessary.
         """
         raise NotImplementedError()
 
-    def match(self, value):
-        """Argument `value` is a :class:`Tree` object."""
+    def match(self, value: Tree) -> bool:
+        """Return ``True`` if ``value`` can be compiled by this action."""
         # pylint: disable=unused-argument
         return False
 
@@ -138,13 +142,13 @@ class Report:
         self._success = success
 
     @property
-    def full_depends(self):
+    def full_depends(self) -> typing.Set[pathlib.Path]:
         """Set of files this action depends on, including ``self.path``."""
         return self.depends | set([self.path.from_fs])
 
     @property
-    def success(self):
-        """Success getter"""
+    def success(self) -> bool:
+        """Was compilation sucessful?"""
         return self._success
 
     @success.setter
