@@ -18,7 +18,7 @@
 import shlex
 import sys
 
-from evariste.plugins.action.command import Command
+from .command import Command
 
 if sys.version_info >= (3, 8, 0):
     join = shlex.join
