@@ -1,4 +1,4 @@
-# Copyright Louis Paternault 2015-2021
+# Copyright Louis Paternault 2015-2022
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -13,25 +13,37 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Render tree as an HTML (body) page."""
+"""Render tree as an HTML (body) page.
 
+.. autoclass:: HTMLRenderer
+   :members:
+
+"""
+
+import contextlib
 import datetime
 import logging
 
-from evariste import VERSION
-from evariste.plugins.renderer.jinja2 import JinjaRenderer
-from evariste.utils import expand_path, smart_open
-
-from . import file, readme
+from .... import VERSION
+from ..jinja2 import Jinja2Renderer
+from . import file
 
 
-class HTMLRenderer(JinjaRenderer):
-    """Render tree as an HTML div (without the `<div>` tags)."""
+class HTMLRenderer(Jinja2Renderer):
+    """Render tree as an HTML div (without the ``<div>`` tags).
+
+    The default template name is ``tree.html``,
+    and such a default template is found in one of the template directories.
+    """
 
     # pylint: disable=too-few-public-methods
 
     keyword = "renderer.html"
-    extension = "html"
+
+    #: Default template.
+    #: This can be overloaded in the setup file.
+    #: The template is looked for in any of the :ref:`templatedirs <jinja2_options>`.
+    template: str = "tree.html"
     default_setup = {"href_prefix": "", "destfile": "index.html"}
     depends = ["renderer.html.readme.html", "renderer.html.file.default"]
     default_templatevar = {
@@ -40,9 +52,3 @@ class HTMLRenderer(JinjaRenderer):
             VERSION, datetime.datetime.now().strftime("%c")
         )
     }
-
-    def render(self, tree):
-        rendered = super().render(tree)
-        with smart_open(expand_path(self.local.setup["destfile"]), "w") as destfile:
-            destfile.write(rendered)
-        return rendered
