@@ -15,7 +15,7 @@
 
 """Render images as HTML"""
 
-from evariste.plugins.renderer.html.file import HtmlFileRenderer
+from . import HtmlFileRenderer
 
 IMAGE_EXTENSIONS = ["png", "jpg", "jpeg", "gif"]
 
