@@ -1,4 +1,4 @@
-# Copyright Louis Paternault 2015-2020
+# Copyright Louis Paternault 2015-2022
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -13,13 +13,21 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Raw README plugin for html renderer."""
+"""Raw README plugin for html renderer.
 
-from evariste.plugins.renderer.jinja2.readme import Jinja2ReadmeRenderer
+.. autoclass:: HtmlReadmeRenderer
+   :members:
+
+"""
+
+from ...jinja2.readme import Jinja2ReadmeRenderer
 
 
 class HtmlReadmeRenderer(Jinja2ReadmeRenderer):
-    """Html renderer for readme files, using jinja2 template engine."""
+    """Html renderer for readme files, using jinja2 template engine.
+
+    It uses the row content of the ``html`` README.
+    """
 
     # pylint: disable=too-few-public-methods, abstract-method
 
