@@ -1,4 +1,4 @@
-# Copyright Louis Paternault 2015-2021
+# Copyright Louis Paternault 2015-2022
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -17,7 +17,7 @@
 
 from docutils import core
 
-from evariste.plugins.renderer.html.readme import HtmlReadmeRenderer
+from . import HtmlReadmeRenderer
 
 
 class RestReadmeRenderer(HtmlReadmeRenderer):
@@ -28,12 +28,12 @@ class RestReadmeRenderer(HtmlReadmeRenderer):
     keyword = "renderer.html.readme.rst"
     extensions = ["rst", "rest"]
 
-    def render(self, path, context):
+    def render(self, tree):
         """Render file as html code."""
-        with open(path, encoding="utf8") as source:
+        with open(tree.from_fs, encoding="utf8") as source:
             return core.publish_parts(
                 source=source.read(),
-                source_path=path,
+                source_path=str(tree.from_fs),
                 # destination_path=destination_path,
                 writer_name="html",
                 settings_overrides={
