@@ -1,4 +1,4 @@
-# Copyright Louis Paternault 2017-2021
+# Copyright Louis Paternault 2017-2022
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -17,11 +17,11 @@
 
 import datetime
 import os
+
 import pkg_resources
 
-from evariste import VERSION
-from evariste import utils
-from evariste.plugins.renderer.html import HTMLRenderer
+from .... import VERSION, utils
+from ..html import HTMLRenderer
 
 
 class HTMLPlusRenderer(HTMLRenderer):
