@@ -25,7 +25,7 @@ from evariste.setup import Setup
 class TestLoadedPlugins(unittest.TestCase):
     """Load plugins"""
 
-    mandatory_plugins = MANDATORY_PLUGINS | {"vcs.none"}
+    mandatory_plugins = MANDATORY_PLUGINS | {"vcs.none", "logging.quiet"}
 
     @staticmethod
     def _loaded_plugins(local):
@@ -39,7 +39,10 @@ class TestLoadedPlugins(unittest.TestCase):
                     "vcs": "vcs.none",
                     "source": ".",
                     "plugins": ["vcs.none"],
-                }
+                },
+                "logging": {
+                    "logger": "quiet",
+                },
             }
         )
         setup.update(local, extend_list=True)
