@@ -1,4 +1,4 @@
-# Copyright Louis Paternault 2015
+# Copyright Louis Paternault 2015-2022
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -18,7 +18,7 @@
 from evariste import plugins
 
 
-class Bar(plugins.PluginBase):
+class Bar(plugins.Plugin):
     """Dummy plugin"""
 
     keyword = "bar"
