@@ -1,4 +1,4 @@
-# Copyright Louis Paternault 2015-2021
+# Copyright Louis Paternault 2015-2022
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -38,7 +38,7 @@ class TestDefaultSetup(TestLoadedPlugins):
         """Test default and required plugins."""
         self.assertSetEqual(
             self._loaded_plugins({"setup": {"libdirs": DEPENDSDIR}}),
-            self.default_plugins,
+            self.mandatory_plugins,
         )
 
     def test_disable_default(self):
@@ -54,7 +54,7 @@ class TestDefaultSetup(TestLoadedPlugins):
                     },
                 }
             ),
-            self.default_plugins,
+            self.mandatory_plugins,
         )
 
     def test_non_existent_plugin(self):
@@ -65,7 +65,7 @@ class TestDefaultSetup(TestLoadedPlugins):
                     {
                         "setup": {
                             "libdirs": DEPENDSDIR,
-                            "enable_plugins": ["nonexistent"],
+                            "plugins": ["nonexistent"],
                         }
                     }
                 )
@@ -76,7 +76,7 @@ class TestDefaultSetup(TestLoadedPlugins):
                     {
                         "setup": {
                             "libdirs": DEPENDSDIR,
-                            "enable_plugins": ["nonexistentdependency"],
+                            "plugins": ["nonexistentdependency"],
                         }
                     }
                 )
@@ -89,11 +89,11 @@ class TestDefaultSetup(TestLoadedPlugins):
                     {
                         "setup": {
                             "libdirs": DEPENDSDIR,
-                            "enable_plugins": ["dependsfoo"],
+                            "plugins": ["dependsfoo"],
                         }
                     }
                 ),
-                set(["dependsfoo", "foo"]) | self.default_plugins,
+                set(["dependsfoo", "foo"]) | self.mandatory_plugins,
             )
 
         with self.subTest():
@@ -108,7 +108,7 @@ class TestDefaultSetup(TestLoadedPlugins):
                         },
                     }
                 ),
-                set(["dependsfoo", "foo"]) | self.default_plugins,
+                set(["dependsfoo", "foo"]) | self.mandatory_plugins,
             )
 
     def test_depends_recursive(self):
@@ -118,7 +118,7 @@ class TestDefaultSetup(TestLoadedPlugins):
                 {
                     "setup": {
                         "libdirs": DEPENDSDIR,
-                        "enable_plugins": ["dependsfoo2"],
+                        "plugins": ["dependsfoo2"],
                     }
                 }
             ),
@@ -129,25 +129,25 @@ class TestDefaultSetup(TestLoadedPlugins):
                     "foo",
                 ]
             )
-            | self.default_plugins,
+            | self.mandatory_plugins,
         )
 
     def test_depends_enable(self):
-        """Test precedence of "enable=True" over "enable_plugins"."""
+        """Test precedence of "enable=True" over "plugins"."""
 
         self.assertSetEqual(
             self._loaded_plugins(
                 {
                     "setup": {
                         "libdirs": DEPENDSDIR,
-                        "enable_plugins": ["foo"],
+                        "plugins": ["foo"],
                     },
                     "foo": {
                         "enable": "False",
                     },
                 }
             ),
-            self.default_plugins,
+            self.mandatory_plugins,
         )
 
     def test_circular_dependency(self):
@@ -158,12 +158,12 @@ class TestDefaultSetup(TestLoadedPlugins):
                 {
                     "setup": {
                         "libdirs": DEPENDSDIR,
-                        "enable_plugins": ["circular1"],
+                        "plugins": ["circular1"],
                     },
                     "foo": {
                         "enable": "False",
                     },
                 }
             ),
-            {"circular1", "circular2"} | self.default_plugins,
+            {"circular1", "circular2"} | self.mandatory_plugins,
         )
