@@ -23,7 +23,7 @@ from evariste.builder import Builder
 def default_shared():
     """Return a default, as empty as possible, :class:`evariste.shared.Shared` object."""
     return Builder.from_setupdict(
-        {"setup": {"vcs": "vcs.none", "enable_plugins": ["vcs.none"]}}
+        {"setup": {"vcs": "vcs.none", "plugins": ["vcs.none"]}}
     ).shared
 
 
